@@ -2,8 +2,8 @@
  * Attacks management core
  *
  * Yersinia
- * By David Barroso <tomac@wasahero.org> and Alfredo Andres <slay@wasahero.org>
- * Copyright 2005 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
+ * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +22,7 @@
 
 #ifndef lint
 static const char rcsid[] =
-       "$Id: attack.c 2 2006-04-03 21:04:25Z tomac $";
+       "$Id: attack.c 46 2007-05-08 09:13:30Z slay $";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -323,9 +323,7 @@ attack_filter_all_params(struct attack_param *attack_param, u_int8_t nparams, u_
                                 attack_param[j].value,
                                 attack_param[j].print,
                                 attack_param[j].size_print,
-                                attack_param[j].min,
-                                attack_param[j].max
-                                ) < 0 )
+                                attack_param[j].size ) < 0 )
        {
           *field = j;
           return -1;
