@@ -1,11 +1,11 @@
 /* attack.h
  * Definitions for attacks management core
  *
- * $Id: attack.h 2 2006-04-03 21:04:25Z tomac $ 
+ * $Id: attack.h 46 2007-05-08 09:13:30Z slay $ 
  *
  * Yersinia
- * By David Barroso <tomac@wasahero.org> and Alfredo Andres <slay@wasahero.org>
- * Copyright 2005 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
+ * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -46,7 +46,7 @@ extern void   write_log( u_int16_t mode, char *msg, ... );
 extern int8_t parser_vrfy_mac( char *, u_int8_t *);
 extern int8_t parser_vrfy_bridge_id( char *, u_int8_t *);
 extern int8_t parser_get_inet_aton(char *, struct in_addr *);
-extern int8_t parser_filter_param(u_int8_t, void *, char *, u_int16_t, int32_t, int32_t);
+extern int8_t parser_filter_param(u_int8_t, void *, char *, u_int16_t, u_int16_t);
 
 #endif
 /* vim:set tabstop=4:set expandtab:set shiftwidth=4:set textwidth=78: */
