@@ -2,8 +2,8 @@
  * Protocols stuff
  *
  * Yersinia
- * By David Barroso <tomac@wasahero.org> and Alfredo Andres <slay@wasahero.org>
- * Copyright 2005 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
+ * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +22,7 @@
 
 #ifndef lint
 static const char rcsid[] =
-"$Id: protocols.c 17 2006-04-17 21:02:28Z tomac $";
+"$Id: protocols.c 43 2007-04-27 11:07:17Z slay $";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -181,6 +181,7 @@ protocol_register_all(void)
     { extern void vtp_register(void);   vtp_register();   }
     { extern void arp_register(void);   arp_register();   }
     { extern void dot1x_register(void); dot1x_register(); }
+    { extern void mpls_register(void);  mpls_register(); }
 }
 
 
