@@ -2,8 +2,8 @@
  * Command line client and application main entry point
  *
  * Yersinia
- * By David Barroso <tomac@wasahero.org> and Alfredo Andres <slay@wasahero.org>
- * Copyright 2005 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
+ * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +22,7 @@
 
 #ifndef lint
 static const char rcsid[] = 
-"$Id: yersinia.c 15 2006-04-10 20:42:06Z tomac $";
+"$Id: yersinia.c 43 2007-04-27 11:07:17Z slay $";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -181,8 +181,7 @@ main( int argc, char **argv )
 
    if ( argc == 1 )                                                          
    {
-      printf("GNU %s %s %s\n", PACKAGE, VERSION,
-            "$Date: 2006/03/23 08:40:14 $");
+      printf("GNU %s %s\n", PACKAGE, VERSION);
       printf("Try '%s -h' to display the help.\n",PACKAGE);
       clean_exit();
    }
